<template>
  <a-modal :confirmLoading='confirmLoading' :maskClosable='false' :okButtonProps='{ props: {disabled: disableSubmit} }' :title='title' :visible='visible'
           :width='500' cancelText='关闭' @cancel='handleCancel' @ok='handleOk'>
    <a-spin :spinning='confirmLoading'>
      <a-form :form='form'>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='参数组编号'>
              <a-input v-decorator="[ 'code', validatorRules.code]" :disabled='disableSubmit' :maxLength='10' :readOnly='disableSubmit'
                       allow-clear placeholder='请输入参数组编号' />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='参数组名称'>
              <a-input v-decorator="[ 'name', validatorRules.name]" :disabled='disableSubmit' :maxLength='20' :readOnly='disableSubmit'
                       allow-clear placeholder='请输入参数组名称' />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='采集等级'>
              <a-select v-model='gradeValue' style='width: 287px'>
                <a-select-option v-for='drive in collectGrade' :key='drive.key'>
                  {{ drive.name }}
                </a-select-option>
              </a-select>
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='备注'>
              <a-textarea v-decorator="['remark', validatorRules.remark]" :disabled='disableSubmit' :readOnly='disableSubmit' allow-clear
                          placeholder='请输入备注' />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>
    <template v-if='disableSubmit == false' slot='footer'>
      <a-button :style="{ marginRight: '8px' }" @click='handleCancel'>关闭</a-button>
      <a-button type='primary' @click='handleOk'>确定</a-button>
    </template>
  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { httpAction } from '@/api/manage'

export default {
  props: [
    'serverId'
  ],
  name: 'ParameterGroupModel',
  data() {
    return {
      gradeValue: '',
      title: '',
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 7 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 14 }
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      collectGrade: [
        {
          key: '1000',
          name: '一级'
        },
        {
          key: '5000',
          name: '二级'
        },
        {
          key: '10000',
          name: '三级'
        }
      ],
      validatorRules: {
        name: {
          rules: [{
            required: true,
            message: '请输入参数组名称'
          }]
        },
        code: {
          rules: [{
            required: true,
            message: '此输入框仅允许输入数字和字母',
            pattern: /^[a-zA-Z0-9]+$/
          }]
        }
      },
      url: {
        add: '/parameter/group/add',
        edit: '/parameter/group/edit'
      },
      disableSubmit: false
    }
  },

  methods: {
    add() {
      this.edit({})
    },
    edit(record) {
      this.form.resetFields()
      this.model = Object.assign({}, record)
      this.visible = true
      if (!this.model.id) {
        this.gradeValue = this.collectGrade[0].key
      } else {
        this.gradeValue = this.model.collectionCycle // 采集等级
      }
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'name', 'code', 'remark'))
      })
    },
    close() {
      this.$emit('close')
      this.visible = false
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true
          let formData = Object.assign(this.model, values)
          let obj
          if (!this.model.id) {
            formData.equipmentId = this.serverId // 设备
            formData.collectionCycle = this.gradeValue // 采集等级
            obj = httpAction(this.url.add, formData, 'post')
          } else {
            formData.collectionCycle = this.gradeValue // 采集等级
            obj = httpAction(this.url.edit, formData, 'put')
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok', res.result)
              that.close()
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
          })
        }
      })
    },
    handleCancel() {
      this.close()
    }
  }
}
</script>

